<?php

$pages_links = "";

if (!($page_number == 1)) {
	$pages_links .= "<a href=\"";
	$pages_links .= $ME . "?page_number=1";
	$pages_links .= "\">";
	$pages_links .= "<b>&lt;&lt;</b>";
	$pages_links .= "</a>&nbsp;&nbsp;";
	$pages_links .= "<a href=\"";
	$pages_links .= $ME . "?page_number=";
	$appoggio = $page_number - 1;
	$pages_links .= $appoggio;
	$pages_links .= "\">";
	$pages_links .= "<b>&lt;</b>";
	echo "</a>&nbsp;&nbsp;";
	for ($i=1; $i<$page_number; $i++) {
		$pages_links .= "<a href=\"";
		$pages_links .= $ME . "?page_number=" . $i;
		$pages_links .= "\">";
		$pages_links .= $i;
		$pages_links .= "</a>&nbsp;&nbsp;";
	}
}
$pages_links .= "<b><font color=\"#ff0000\">" . $page_number . "</font></b>&nbsp;&nbsp;";
if (!($page_number == $num_pages)) {
	for ($i=$page_number+1; $i<=$num_pages; $i++) {
		$pages_links .= "<a href=\"";
		$pages_links .= $ME . "?page_number=" . $i;
		$pages_links .= "\">";
		$pages_links .= $i;
		$pages_links .= "</a>&nbsp;&nbsp;";
	}
	$pages_links .= "<a href=\"";
	$pages_links .= $ME . "?page_number=";
	$appoggio = $page_number + 1;
	$pages_links .= $appoggio;
	$pages_links .= "\">";
	$pages_links .= "<b>&gt;</b>";
	$pages_links .= "</a>&nbsp;&nbsp;";
	$pages_links .= "<a href=\"";
	$pages_links .= $ME . "?page_number=" . $num_pages;
	$pages_links .= "\">";
	$pages_links .= "<b>&gt;&gt;</b>";
	$pages_links .= "</a>&nbsp;&nbsp;";
}

?>
